# Default level indent when reading a text document as a tree
DEFAULT_INDENT = 2

# Maximum number of words for a paragraph, in the relecant chunk modes
DEFAULT_MAX_WORDS = 100

# Implemented chunking modes
CHUNK_MODES = ("single", "line", "tree", "paragraph", "word")
